@@ -86,7 +86,7 @@
 #define KARCHIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KARCHIVE_NO_DEPRECATED
-#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KARCHIVE_NO_DEPRECATED_WARNINGS
 #  define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KARCHIVE_DEPRECATED_WARNINGS_SINCE KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -186,7 +186,7 @@
 #define KARCHIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KARCHIVE_NO_DEPRECATED
-#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KARCHIVE_NO_DEPRECATED_WARNINGS
 #  define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -196,7 +196,7 @@
 #  ifdef KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KARCHIVE_DEPRECATED_WARNINGS_SINCE KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
